@@ -13,6 +13,12 @@ import aws_cdk.aws_lambda
 import aws_cdk.aws_sns
 import aws_cdk.core
 import aws_solutions_konstruk.core
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-konstruk/aws-lambda-sns", "0.8.1", __name__[0:-6], "aws-lambda-sns@0.8.1.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
